Keywords: figures,movies,index with subindex,_boldface word_ in index,index with _boldface word_,index with _boldface word_ in subentry,double _boldface word_ _boldface word_ in subentry too,index, with comma, and one more

# A Document for Testing DocOnce

Hans Petter Langtangen [1, 2] (`hpl at simula.no`)
Kaare Dump [3]
A. Dummy Author
I. S. Overworked and Outburned [4, 5, 6, 7]
J. Doe (`j_doe at cyberspace.com`)

[1] Center for Biomedical Computing, Simula Research Laboratory
[2] Department of Informatics, University of Oslo
[3] Segfault, Cyberspace
[4] Inst1
[5] Inst2, Somewhere
[6] Third Inst, Elsewhere
[7] Fourth Inst

#### Mar 1, 2021

# Table of contents

Section 1
Subsection 1
Subsection 2: Testing figures
The \( \theta \) parameter (not \( \nabla \)?)
Custom Environments
Tables
A test of verbatim words in heading with subscript \( a_i \): `my_file_v1` and `my_file_v2`
Just bold
Just emphasize
`Just verbatim`
Bold beginning
Emphasize beginning
`Verbatim` beginning
Maybe bold end
Maybe emphasize end
Maybe `verbatim end`
The middle has bold word
The middle has emphasize word
The middle has `verbatim` word
Bibliography test
Example 1: Examples can be typeset as exercises
User-defined environments
Example 1: A test function
Example 2: Addition
URLs
LaTeX Mathematics
Exercises
Problem 2: Flip a Coin
Not an exercise
Exercise 3: Test of plain text exercise
Project 4: Compute a Probability
Project 5: Explore Distributions of Random Circles
Exercise 6: Determine some Distance
Some exercise without the "Exercise:" prefix
Exercise 8: Solution of differential equation
Example 9: Just an example
Here goes another section
More Exercises
Exercise 10: Make references to projects and problems
Project 11: References in a headings do not work well in html
References
Appendix: Just for testing; part I
A subsection within an appendix
Appendix: Just for testing; part II
Appendix: Testing identical titles
Appendix: Testing identical titles
Appendix: Testing identical titles
Appendix: Testing identical titles
Appendix: Testing inline comments
Appendix: Testing headings ending with `verbatim inline`

| \